<?php

defined('HOSTCMS') || exit('HostCMS: access denied.');

/**
* Обработчик триггера от retailCRM.
* 
* @author Maxim Zasorin, KAD Systems (©) 2017
* @date 07-12-2017
*/
class Kad_Retailcrm_Webhook
{
	/**
	 * Данные.
	 *
	 * @var StdClass
	 */
	protected $_data;

	/**
	 * Создает объект с данными.
	 * 
	 * @param  string  $sData
	 * @return Kad_Retailcrm_Webhook
	 */
	static public function create($sData)
	{
		// Логгируем данные
		Kad_Retailcrm_Client::log('retailCRM Webhook: ' . preg_replace('/\s+/', '', $sData), Core_Log::$SUCCESS);

		// Проверяем корректность данных
		$oData = json_decode($sData);

		if (!$oData)
		{
			Kad_Retailcrm_Client::log('Ошибка при разборе данных.', Core_Log::$ERROR);

			return NULL;
		}

		// Проверяем секретное слово
		$aConfig = Core_Config::instance()->get('kad_retailcrm_config');

		if (!isset($oData->secret_sequence) || $oData->secret_sequence != $aConfig['secret_sequence'])
		{
			Kad_Retailcrm_Client::log('Неверное секретное слово.', Core_Log::$ERROR);

			return NULL;
		}

		unset($oData->secret_sequence);

		return new self($oData);
	}

	/**
	 * Геттер для данных.
	 *
	 * @return StdClass
	 */
	public function getData()
	{
		return $this->_data;
	}

	/**
	 * Конструктор.
	 *
	 * @param  string  $sData
	 * @return void
	 */
	protected function __construct($sData)
	{
		$this->_data = $sData;
	}
}